package com.wastedpotential {
	import flash.events.Event;
	import org.flixel.*;
 
	public class PlayState extends FlxState	{
		
		[Embed(source="/../media/map.txt", mimeType="application/octet-stream")] protected var mapString:Class;	
		[Embed(source = "/../media/newTiles32.png")] protected var newTiles:Class;
		[Embed(source="/../media/candle.png")] protected var CandleImage:Class;
		[Embed(source="/../media/clouds.jpg")] protected var CloudImage:Class;
		[Embed(source="/../media/exit.png")] protected var ExitImage:Class;
		
		protected var player:Player = null;
		protected var exit:FlxSprite = null;
		protected var candles:FlxGroup = null;
		//protected var floor:FlxTileblock = null;
		protected var groundMap:FlxTilemap = new FlxTilemap();
		protected var camera:FlxCamera = new FlxCamera(0, 0, FlxG.width, FlxG.height);
		protected var bg:FlxSprite = new FlxSprite(0, 0);
		protected var scoreText:FlxText;
		
		protected const SCORE_TEXT:String = "Candles Collected: ";
		
		override public function create():void {
			//trace("PlayState :: create");
			
			//add bg:
			bg.loadGraphic(CloudImage, false, false, 800, 256, false);
			bg.scrollFactor = new FlxPoint(0.25, 1); //scroll the bg graphic slowly for parallax effect
			this.add(bg);
			
			//add level tilemap:
			groundMap.loadMap(new mapString, newTiles, GameModel.tileSize, GameModel.tileSize);
			this.add(groundMap);
			
			//add candle collectibles:
			candles = new FlxGroup();
			createCandle(4, 3); //a
			createCandle(5, 1);
			createCandle(6, 1);
			createCandle(8, 2); //p
			createCandle(9, 2);
			createCandle(10, 2);
			createCandle(12, 1); //p
			createCandle(13, 1);
			createCandle(14, 1);
			createCandle(16, 2); //y
			createCandle(17, 4);
			createCandle(18, 2);
			
			createCandle(20, 1); //b
			createCandle(21, 3);
			createCandle(24, 2); //i
			createCandle(26, 2); //r
			createCandle(27, 2);
			createCandle(28, 2);
			createCandle(30, 2); //t
			createCandle(31, 0);
			createCandle(32, 2);
			createCandle(34, 0); //h
			createCandle(35, 2);
			createCandle(36, 2);
			createCandle(38, 3); //d
			createCandle(40, 1);
			createCandle(43, 4); //a
			createCandle(43, 2);
			createCandle(44, 2);
			createCandle(46, 1); //y
			createCandle(47, 3);
			createCandle(48, 1);
			
			createCandle(50, 0); //T
			createCandle(51, 0);
			createCandle(52, 0);
			createCandle(53, 2); //o
			createCandle(54, 2);
			createCandle(55, 2);
			createCandle(57, 3); //n
			createCandle(58, 3);
			createCandle(59, 3);
			createCandle(61, 1); //y
			createCandle(62, 3);
			createCandle(63, 1);
			
			add(candles);
			
			//add exit door
			exit = new FlxSprite(2144, 56);
			exit.loadGraphic(ExitImage, false, false, 32, 40);
			this.add(exit);
			
			//add player
			player = new Player();
			player.x = 50;
			player.y = 100;
			this.add(player);
			
			//add scoretext
			scoreText = new FlxText(0, 0, 300, SCORE_TEXT+GameModel.score);
			scoreText.scrollFactor = new FlxPoint(0, 1); //DON'T SCROLL THIS!
			this.add(scoreText);
			
			//set up the camera:
			camera.follow(player, FlxCamera.STYLE_PLATFORMER); //follow the player with a slight dead zone
			camera.setBounds(0, 0, groundMap.width, groundMap.height); //make sure you don't go past the edge of the tilemap
			FlxG.addCamera(camera); //add the camera
			FlxG.worldBounds = new FlxRect(0, 0, groundMap.width, groundMap.height); //need this to tell flixel where to calculate collisions
			
			super.create();
		}			
		
		//- the onEnterFrame function
		override public function update():void {
			//trace("PlayState :: update " + groundMap.x);
			FlxG.overlap(candles, player, getCandle); //if you touch a candle... go to getCandle()
			FlxG.overlap(exit, player, exitNow); //if you touch the exit door... go to exitNow()	
			FlxG.collide(player, groundMap); //keep the player on the tilemap
			super.update();						
		}
		
		//Called whenever the player touches a candle
		public function getCandle(candle:FlxSprite, player:FlxSprite):void {
			//trace("PlayState :: getCandle");
			candle.kill(); //remove the candle from the screen and the collision tests
			GameModel.score++; //increment the score
			scoreText.text = SCORE_TEXT + GameModel.score; //uppdate the score text
			//trace("SCORE: "+(candles.countDead()*100));
			if(candles.countLiving() == 0) { //if there are no candles left, display exit message
				scoreText.text = "Use the exit.";				
			}
		}
		
		//- Called whenever the player touches the exit
		public function exitNow(exit:FlxSprite, player:FlxSprite):void {
			//trace("PlayState :: exitNow");
			FlxG.switchState(new FinalState());
		}
		
		//- creates a new candle located on the specified tile position
		protected function createCandle(X:uint,Y:uint):void {
			//trace("PlayState :: createCandle");
			var candle:FlxSprite = new FlxSprite(X * GameModel.tileSize + 12, Y * GameModel.tileSize);
			candle.loadGraphic(CandleImage, false, false, 7, 35, false);
			candles.add(candle);
		}
		
	}
}